@@ -77,8 +77,11 @@ ztpoisson <- function(lambdaLink = c("log", "neglog"),
       offset <- cbind(rep(0, NROW(X)))
     }
     
-    if (!(deriv %in% c(0, 1, 2))) stop("Only score function and derivatives up to 2 are supported.")
-    deriv <- deriv + 1 # to make it conform to how switch in R works, i.e. indexing begins with 1
+    if (!(deriv %in% c(0, 1, 2))) 
+      stop("Only score function and derivatives up to 2 are supported.")
+    
+    # to make it conform to how switch in R works, i.e. indexing begins with 1
+    deriv <- deriv + 1
     
     switch (deriv,
       function(beta) {
@@ -222,7 +225,6 @@ ztpoisson <- function(lambdaLink = c("log", "neglog"),
       etaStart <- cbind(
         pmin(family$links[[1]](observed), family$links[[1]](12))
       ) + offset
-      #etaStart <- etaStart
     } else if (method == "optim") {
       init <- c(
         family$links[[1]](weighted.mean(observed, priorWeights))
